"use client"
import React, { useEffect, useState } from 'react'
import UserTab from '../../components/layout/UserTab'
import useProfile from '../../components/UseProfile'

const OrderPage = () => {
    const {loading, data} = useProfile();
    const [orders, setOrders] = useState([]);


    useEffect(() => {
        fetch('/api/orders').then(res => {
            res.json().then(orders => {
                setOrders(orders);
            })
        })
    }, [])

    //date&time for createdAt
    function dateTime(str){
        return str.replace('T', ' ').substring(0, 16)
    }

    if(loading){
        return <p className='flex justify-center items-center'>Loading...</p>
    }
    if(!data.admin){
        return <p className='flex justify-center items-center'>Please login as an admin</p>
    }


  return (
    <div className='px-5 mb-10'>
        <UserTab isAdmin={true}/>
        <div className='max-w-md mx-auto mt-10'>
            {orders?.length > 0 && orders.map(order => (
                <div className='border p-2 my-2 w-full rounded-md outline-none border-[#DCA0AE] flex items-center justify-between'>
                    <div className='flex flex-col'>
                        <div className='text-gray-700 font-semibold'>{order.userEmail}</div>
                        <div className={order.paid? 'text-green-600 text-sm' : 'text-red-600 text-sm'}>{order.paid ? 'Paid' : 'Payment required'}</div>
                    </div>
                    <div>
                        {dateTime(order.createdAt)}
                    </div>
                </div>
            ))}
        </div>
    </div>
  )
}

export default OrderPage